@@ -25,11 +25,11 @@ WWW::YoutubeViewer - A very easy interface to YouTube.
 
 =head1 VERSION
 
-Version 3.2.1
+Version 3.2.2
 
 =cut
 
-our $VERSION = '3.2.1';
+our $VERSION = '3.2.2';
 
 =head1 SYNOPSIS
 
@@ -605,6 +605,11 @@ sub _get_pairs_from_info_data {
                 last;
             }
         }
+        elsif (exists $hash_ref->{hlsvp}) {
+            $hash_ref->{itag} = 38;
+            $hash_ref->{type} = 'video/ts';
+            $hash_ref->{url}  = $hash_ref->{hlsvp};
+        }
     }
 
     return @array;
